==> oct8ne-v.1.2.8.zip: oct8ne/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = [];
$_MODULE['<{oct8ne}prestashop>oct8ne_bc741b828f1fc35a6f10c870d6056343'] = 'Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8ff7439dd2ee3184597be0c738ad566a'] = 'Connecteur de module Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_a9390206b02d5d06ee405aa6b4d7b232'] = 'Toutes les données seront supprimées ¿continuer?';
$_MODULE['<{oct8ne}prestashop>oct8ne_004b04925fa8a42d0d28c3862c6947bd'] = 'Impossible de vous connecter, veuillez vérifier vos informations d\'identification';
$_MODULE['<{oct8ne}prestashop>oct8ne_5f2faa4c7bc8b0d9862218f744a1aee3'] = 'Oct8ne Paramètres';
$_MODULE['<{oct8ne}prestashop>oct8ne_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{oct8ne}prestashop>oct8ne_3d236caa22b35b852d3d9f402ecd361d'] = 'Votre email ...';
$_MODULE['<{oct8ne}prestashop>oct8ne_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{oct8ne}prestashop>oct8ne_45e37dc42e288221084fc298cd93c8bb'] = 'Votre Mot de passe';
$_MODULE['<{oct8ne}prestashop>oct8ne_98045f7a4e566c2167bac30218c338ac'] = 'Vous devez remplir les champs avec vos informations d\'utilisateur du panneau d\'administration sur Oct8ne. Si vous n\'avez toujours pas de nom d\'utilisateur Oct8ne, vous pouvez en créer un';
$_MODULE['<{oct8ne}prestashop>oct8ne_6c92285fa6d3e827b198d120ea3ac674'] = 'ici';
$_MODULE['<{oct8ne}prestashop>oct8ne_99dea78007133396a7b8ed70578ac6ae'] = 'S\'identifier';
$_MODULE['<{oct8ne}prestashop>oct8ne_87e9c089875dbf587734df396ce7423a'] = 'Moteur de recherche prestashop par défaut';
$_MODULE['<{oct8ne}prestashop>oct8ne_afaa5ee5fcca30cc8ab8b7b8096d76b8'] = 'Doofinder moteur de recherche';
$_MODULE['<{oct8ne}prestashop>oct8ne_ede9e64250ae298e24874dfe3c23c567'] = 'Oct8ne moteur de recherche';
$_MODULE['<{oct8ne}prestashop>oct8ne_14e69b495b4ad97a1c4a468d99169b21'] = 'Moteur de recherche';
$_MODULE['<{oct8ne}prestashop>oct8ne_daa6b483e9f6ca081ec7e0b4a352f9e9'] = 'Sauvegarder les modifications';
$_MODULE['<{oct8ne}prestashop>oct8ne_d2cb1b13319e5118823778f3e4505f41'] = 'Oct8ne info';
$_MODULE['<{oct8ne}prestashop>oct8ne_8d1bd3e5756e3454644c531701ff73e0'] = 'Utilisateur actif:';
$_MODULE['<{oct8ne}prestashop>oct8ne_0323de4f66a1700e2173e9bcdce02715'] = 'Connectez - Out';
$_MODULE['<{oct8ne}prestashop>oct8ne_3168ca6855e90fdc6ef9a9022b747df3'] = 'Oct8ne options';
$_MODULE['<{oct8ne}prestashop>oct8ne_031cf59f5628f2828e2433d82aa26c7a'] = 'Vous pouvez choisir la position pour charger les scripts Oct8ne (En pied de page ou En-tête) de la page';
$_MODULE['<{oct8ne}prestashop>oct8ne_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{oct8ne}prestashop>oct8ne_1c8d7e5020585439fe9972e6288b3687'] = 'Type d\'image URL';
$_MODULE['<{oct8ne}prestashop>oct8ne_a743c9120ecd8b14ccf16ed8d12a68d9'] = 'Le type 1 ajoute l\'identifiant du produit avant l\'identification de l\'image. Utile dans des cas spécifiques. Attention, changez cette option seulement si nécessaire';
$_MODULE['<{oct8ne}prestashop>oct8ne_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0d07cb35250063972daeb65e388ee3d'] = 'Configuration de base - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{oct8ne}prestashop>customerconfig_7075e53a2135d5c3d687fd5a6966e24d'] = 'En-tête';
$_MODULE['<{oct8ne}prestashop>customerconfig_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'En pied de page';
$_MODULE['<{oct8ne}prestashop>customerconfig_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Vous pouvez choisir où charger les scripts oct8ne: Dans le pied de page ou dans l\'en-tête de votre page';
$_MODULE['<{oct8ne}prestashop>customerconfig_3284614a26b9eebe62398c0174743691'] = 'Type d\'images';
$_MODULE['<{oct8ne}prestashop>customerconfig_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standar';
$_MODULE['<{oct8ne}prestashop>customerconfig_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Type 1';
$_MODULE['<{oct8ne}prestashop>customerconfig_2141d9976decee64d296a8c3146ab839'] = 'Le type 1 ajoute l\'identifiant du produit devant l\'identifiant de l\'image. Utile dans des cas spécifiques. Attention, ne modifiez cette option que si nécessaire v chien';
$_MODULE['<{oct8ne}prestashop>customerconfig_c9cc8cce247e49bae79f15173ce97354'] = 'sauvegarder';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0cc842d01c1807510e37fe22f4d2d67'] = 'Moteur de recherche - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_7bfa30721c5e726ff17e3f972237a82c'] = 'Moteur';
$_MODULE['<{oct8ne}prestashop>customerconfig_935565d6f7077f17422708654b138b47'] = 'Moteur de recherche à utiliser';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0d07cb35250063972daeb65e388ee3d'] = 'Configuration de base - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7075e53a2135d5c3d687fd5a6966e24d'] = 'En-tête';
$_MODULE['<{oct8ne}prestashop>customerconfig7_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'En pied de page';
$_MODULE['<{oct8ne}prestashop>customerconfig7_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Vous pouvez choisir où charger les scripts oct8ne: Dans le pied de page ou dans l\'en-tête de votre page';
$_MODULE['<{oct8ne}prestashop>customerconfig7_3284614a26b9eebe62398c0174743691'] = 'Type d\'images';
$_MODULE['<{oct8ne}prestashop>customerconfig7_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Type 1';
$_MODULE['<{oct8ne}prestashop>customerconfig7_2141d9976decee64d296a8c3146ab839'] = 'Le type 1 ajoute l\'identifiant du produit devant l\'identifiant de l\'image. Utile dans des cas spécifiques. Attention, ne modifiez cette option que si nécessaire v chien';
$_MODULE['<{oct8ne}prestashop>customerconfig7_c9cc8cce247e49bae79f15173ce97354'] = 'sauvegarder';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0cc842d01c1807510e37fe22f4d2d67'] = 'Moteur de recherche - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7bfa30721c5e726ff17e3f972237a82c'] = 'Moteur';
$_MODULE['<{oct8ne}prestashop>customerconfig7_935565d6f7077f17422708654b138b47'] = 'Moteur de recherche à utiliser';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_af1b98adf7f686b84cd0b443e022b7a0'] = 'Les catégories';

==> oct8ne-v.1.3.0.zip: oct8ne/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = [];
$_MODULE['<{oct8ne}prestashop>oct8ne_bc741b828f1fc35a6f10c870d6056343'] = 'Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8ff7439dd2ee3184597be0c738ad566a'] = 'Connecteur de module Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_a9390206b02d5d06ee405aa6b4d7b232'] = 'Toutes les données seront supprimées ¿continuer?';
$_MODULE['<{oct8ne}prestashop>oct8ne_004b04925fa8a42d0d28c3862c6947bd'] = 'Impossible de vous connecter, veuillez vérifier vos informations d\'identification';
$_MODULE['<{oct8ne}prestashop>oct8ne_5f2faa4c7bc8b0d9862218f744a1aee3'] = 'Oct8ne Paramètres';
$_MODULE['<{oct8ne}prestashop>oct8ne_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{oct8ne}prestashop>oct8ne_3d236caa22b35b852d3d9f402ecd361d'] = 'Votre email ...';
$_MODULE['<{oct8ne}prestashop>oct8ne_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{oct8ne}prestashop>oct8ne_45e37dc42e288221084fc298cd93c8bb'] = 'Votre Mot de passe';
$_MODULE['<{oct8ne}prestashop>oct8ne_98045f7a4e566c2167bac30218c338ac'] = 'Vous devez remplir les champs avec vos informations d\'utilisateur du panneau d\'administration sur Oct8ne. Si vous n\'avez toujours pas de nom d\'utilisateur Oct8ne, vous pouvez en créer un';
$_MODULE['<{oct8ne}prestashop>oct8ne_6c92285fa6d3e827b198d120ea3ac674'] = 'ici';
$_MODULE['<{oct8ne}prestashop>oct8ne_99dea78007133396a7b8ed70578ac6ae'] = 'S\'identifier';
$_MODULE['<{oct8ne}prestashop>oct8ne_87e9c089875dbf587734df396ce7423a'] = 'Moteur de recherche prestashop par défaut';
$_MODULE['<{oct8ne}prestashop>oct8ne_afaa5ee5fcca30cc8ab8b7b8096d76b8'] = 'Doofinder moteur de recherche';
$_MODULE['<{oct8ne}prestashop>oct8ne_ede9e64250ae298e24874dfe3c23c567'] = 'Oct8ne moteur de recherche';
$_MODULE['<{oct8ne}prestashop>oct8ne_14e69b495b4ad97a1c4a468d99169b21'] = 'Moteur de recherche';
$_MODULE['<{oct8ne}prestashop>oct8ne_daa6b483e9f6ca081ec7e0b4a352f9e9'] = 'Sauvegarder les modifications';
$_MODULE['<{oct8ne}prestashop>oct8ne_d2cb1b13319e5118823778f3e4505f41'] = 'Oct8ne info';
$_MODULE['<{oct8ne}prestashop>oct8ne_8d1bd3e5756e3454644c531701ff73e0'] = 'Utilisateur actif:';
$_MODULE['<{oct8ne}prestashop>oct8ne_0323de4f66a1700e2173e9bcdce02715'] = 'Connectez - Out';
$_MODULE['<{oct8ne}prestashop>oct8ne_3168ca6855e90fdc6ef9a9022b747df3'] = 'Oct8ne options';
$_MODULE['<{oct8ne}prestashop>oct8ne_031cf59f5628f2828e2433d82aa26c7a'] = 'Vous pouvez choisir la position pour charger les scripts Oct8ne (En pied de page ou En-tête) de la page';
$_MODULE['<{oct8ne}prestashop>oct8ne_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{oct8ne}prestashop>oct8ne_1c8d7e5020585439fe9972e6288b3687'] = 'Type d\'image URL';
$_MODULE['<{oct8ne}prestashop>oct8ne_a743c9120ecd8b14ccf16ed8d12a68d9'] = 'Le type 1 ajoute l\'identifiant du produit avant l\'identification de l\'image. Utile dans des cas spécifiques. Attention, changez cette option seulement si nécessaire';
$_MODULE['<{oct8ne}prestashop>oct8ne_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0d07cb35250063972daeb65e388ee3d'] = 'Configuration de base - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{oct8ne}prestashop>customerconfig_7075e53a2135d5c3d687fd5a6966e24d'] = 'En-tête';
$_MODULE['<{oct8ne}prestashop>customerconfig_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'En pied de page';
$_MODULE['<{oct8ne}prestashop>customerconfig_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Vous pouvez choisir où charger les scripts oct8ne: Dans le pied de page ou dans l\'en-tête de votre page';
$_MODULE['<{oct8ne}prestashop>customerconfig_3284614a26b9eebe62398c0174743691'] = 'Type d\'images';
$_MODULE['<{oct8ne}prestashop>customerconfig_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standar';
$_MODULE['<{oct8ne}prestashop>customerconfig_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Type 1';
$_MODULE['<{oct8ne}prestashop>customerconfig_2141d9976decee64d296a8c3146ab839'] = 'Le type 1 ajoute l\'identifiant du produit devant l\'identifiant de l\'image. Utile dans des cas spécifiques. Attention, ne modifiez cette option que si nécessaire v chien';
$_MODULE['<{oct8ne}prestashop>customerconfig_c9cc8cce247e49bae79f15173ce97354'] = 'sauvegarder';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0cc842d01c1807510e37fe22f4d2d67'] = 'Moteur de recherche - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_7bfa30721c5e726ff17e3f972237a82c'] = 'Moteur';
$_MODULE['<{oct8ne}prestashop>customerconfig_935565d6f7077f17422708654b138b47'] = 'Moteur de recherche à utiliser';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0d07cb35250063972daeb65e388ee3d'] = 'Configuration de base - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Position';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7075e53a2135d5c3d687fd5a6966e24d'] = 'En-tête';
$_MODULE['<{oct8ne}prestashop>customerconfig7_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'En pied de page';
$_MODULE['<{oct8ne}prestashop>customerconfig7_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Vous pouvez choisir où charger les scripts oct8ne: Dans le pied de page ou dans l\'en-tête de votre page';
$_MODULE['<{oct8ne}prestashop>customerconfig7_3284614a26b9eebe62398c0174743691'] = 'Type d\'images';
$_MODULE['<{oct8ne}prestashop>customerconfig7_0663eabe90a1e1578e1a090d82f6d89d'] = 'Standar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Type 1';
$_MODULE['<{oct8ne}prestashop>customerconfig7_2141d9976decee64d296a8c3146ab839'] = 'Le type 1 ajoute l\'identifiant du produit devant l\'identifiant de l\'image. Utile dans des cas spécifiques. Attention, ne modifiez cette option que si nécessaire v chien';
$_MODULE['<{oct8ne}prestashop>customerconfig7_c9cc8cce247e49bae79f15173ce97354'] = 'sauvegarder';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0cc842d01c1807510e37fe22f4d2d67'] = 'Moteur de recherche - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7bfa30721c5e726ff17e3f972237a82c'] = 'Moteur';
$_MODULE['<{oct8ne}prestashop>customerconfig7_935565d6f7077f17422708654b138b47'] = 'Moteur de recherche à utiliser';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_af1b98adf7f686b84cd0b443e022b7a0'] = 'Les catégories';

$_MODULE['<{oct8ne}prestashop>update_notification_bd8334f553a15234208a32961e69a032'] = 'Nouvelle version disponible !';
$_MODULE['<{oct8ne}prestashop>update_notification_552803cb1363989c9339a7d3a04a520e'] = 'Vous utilisez la version';
$_MODULE['<{oct8ne}prestashop>update_notification_d91d8304919741e24744d07b8b4226f7'] = 'Version';
$_MODULE['<{oct8ne}prestashop>update_notification_4901f40398019e07246543b50c021c35'] = 'est disponible.';
$_MODULE['<{oct8ne}prestashop>update_notification_8e35359a0df470e806c99c8509c693a2'] = 'Télécharger v';
